@@ -42,7 +42,7 @@ from jarabe.view import launcher
 from jarabe.model.buddy import BuddyModel
 from jarabe.model import shell
 from jarabe.model import bundleregistry
-from jarabe import journal
+from jarabe.journal import misc
 
 from jarabe.desktop import schoolserver
 from jarabe.desktop.schoolserver import RegisterError
@@ -92,6 +92,7 @@ class FavoritesView(hippo.Canvas):
         self._layout = None
         self._alert = None
         self._datastore_listener = DatastoreListener()
+        self._resume_mode = True
 
         # More DND stuff
         self.add_events(gtk.gdk.BUTTON_PRESS_MASK |
@@ -111,7 +112,7 @@ class FavoritesView(hippo.Canvas):
 
     def __settings_changed_cb(self, **kwargs):
         favorites_settings = get_settings()
-        self._set_layout(favorites_settings.layout)        
+        self._set_layout(favorites_settings.layout)
 
     def __connect_to_bundle_registry_cb(self):
         registry = bundleregistry.get_registry()
@@ -130,6 +131,7 @@ class FavoritesView(hippo.Canvas):
             return
         icon = ActivityIcon(activity_info, self._datastore_listener)
         icon.props.size = style.STANDARD_ICON_SIZE
+        icon.set_resume_mode(self._resume_mode)
         self._box.insert_sorted(icon, 0, self._layout.compare_activities)
         self._layout.append(icon)
 
@@ -167,7 +169,7 @@ class FavoritesView(hippo.Canvas):
             self._add_activity(activity_info)
 
     def do_size_allocate(self, allocation):
-        width = allocation.width        
+        width = allocation.width
         height = allocation.height
 
         min_w_, my_icon_width = self._my_icon.get_width_request()
@@ -211,7 +213,7 @@ class FavoritesView(hippo.Canvas):
     def __motion_notify_event_cb(self, widget, event):
         if not self._pressed_button:
             return False
-        
+
         # if the mouse button is not pressed, no drag should occurr
         if not event.state & gtk.gdk.BUTTON1_MASK:
             self._pressed_button = None
@@ -237,7 +239,7 @@ class FavoritesView(hippo.Canvas):
         icon_file_name = self._last_clicked_icon.props.file_name
         # TODO: we should get the pixbuf from the widget, so it has colors, etc
         pixbuf = gtk.gdk.pixbuf_new_from_file(icon_file_name)
-        
+
         self._hot_x = pixbuf.props.width / 2
         self._hot_y = pixbuf.props.height / 2
         context.set_icon_pixbuf(pixbuf, self._hot_x, self._hot_y)
@@ -322,7 +324,7 @@ class FavoritesView(hippo.Canvas):
         except RegisterError, e:
             alert.props.title = _('Registration Failed')
             alert.props.msg = _('%s') % e
-        else:    
+        else:
             alert.props.title = _('Registration Successful')
             alert.props.msg = _('You are now registered ' \
                                 'with your school server.')
@@ -332,11 +334,17 @@ class FavoritesView(hippo.Canvas):
         alert.add_button(gtk.RESPONSE_OK, _('Ok'), ok_icon)
 
         self.add_alert(alert)
-        alert.connect('response', self.__register_alert_response_cb)            
-            
+        alert.connect('response', self.__register_alert_response_cb)
+
     def __register_alert_response_cb(self, alert, response_id):
         self.remove_alert()
 
+    def set_resume_mode(self, resume_mode):
+        self._resume_mode = resume_mode
+        for icon in self._box.get_children():
+            if hasattr(icon, 'set_resume_mode'):
+                icon.set_resume_mode(self._resume_mode)
+
 DS_DBUS_SERVICE = 'org.laptop.sugar.DataStore'
 DS_DBUS_INTERFACE = 'org.laptop.sugar.DataStore'
 DS_DBUS_PATH = '/org/laptop/sugar/DataStore'
@@ -370,7 +378,7 @@ class DatastoreListener(object):
     def get_last_activity_async(self, bundle_id, properties, callback_cb):
         query = {'activity': bundle_id,
                  'limit': 5,
-                 'order_by': ['-mtime']}
+                 'order_by': ['+timestamp']}
 
         reply_handler = lambda entries, total_count: self.__reply_handler_cb(
                 entries, total_count, callback_cb)
@@ -379,8 +387,8 @@ class DatastoreListener(object):
                 error, callback_cb)
 
         self._datastore.find(query, properties, byte_arrays=True,
-                               reply_handler=reply_handler,
-                               error_handler=error_handler)
+                             reply_handler=reply_handler,
+                             error_handler=error_handler)
 
     def __reply_handler_cb(self, entries, total_count, callback_cb):
         logging.debug('__reply_handler_cb')
@@ -402,6 +410,7 @@ class ActivityIcon(CanvasIcon):
         self._activity_info = activity_info
         self._journal_entries = []
         self._hovering = False
+        self._resume_mode = True
 
         self.connect('hovering-changed', self.__hovering_changed_event_cb)
         self.connect('button-release-event', self.__button_release_event_cb)
@@ -433,7 +442,8 @@ class ActivityIcon(CanvasIcon):
 
     def __get_last_activity_async_cb(self, entries, error=None):
         if error is not None:
-            logging.error('Error retrieving most recent activities: %r' % error)
+            logging.error('Error retrieving most recent activities: %r', error)
+            return
 
         # If there's a problem with the DS index, we may get entries not related
         # to this activity.
@@ -447,21 +457,25 @@ class ActivityIcon(CanvasIcon):
 
     def _update(self):
         self.palette = None
-        if not self._journal_entries:
-            self.props.stroke_color = style.COLOR_BUTTON_GREY.get_svg()
-            self.props.fill_color = style.COLOR_TRANSPARENT.get_svg()
+        if not self._resume_mode or not self._journal_entries:
+            xo_color = XoColor('%s,%s' % (style.COLOR_BUTTON_GREY.get_svg(),
+                                          style.COLOR_TRANSPARENT.get_svg()))
         else:
-            first_entry = self._journal_entries[0]
-            self.props.xo_color = XoColor(first_entry['icon-color'])
+            xo_color = misc.get_icon_color(self._journal_entries[0])
+        self.props.xo_color = xo_color
 
     def create_palette(self):
         palette = FavoritePalette(self._activity_info, self._journal_entries)
         palette.connect('activate', self.__palette_activate_cb)
+        palette.connect('entry-activate', self.__palette_entry_activate_cb)
         return palette
 
     def __palette_activate_cb(self, palette):
         self._activate()
 
+    def __palette_entry_activate_cb(self, palette, metadata):
+        self._resume(metadata)
+
     def __hovering_changed_event_cb(self, icon, hovering):
         self._hovering = hovering
         self.emit_paint_needed(0, 0, -1, -1)
@@ -492,7 +506,7 @@ class ActivityIcon(CanvasIcon):
         cr.stroke()
 
     def do_get_content_height_request(self, for_width):
-        height, height = CanvasIcon.do_get_content_height_request(self, 
+        height, height = CanvasIcon.do_get_content_height_request(self,
                                                                   for_width)
         height += ActivityIcon._BORDER_WIDTH * 2
         return height, height
@@ -505,24 +519,17 @@ class ActivityIcon(CanvasIcon):
     def __button_release_event_cb(self, icon, event):
         self._activate()
 
+    def _resume(self, journal_entry):
+        if not journal_entry['activity_id']:
+            journal_entry['activity_id'] = activityfactory.create_activity_id()
+        misc.resume(journal_entry, self._activity_info.get_bundle_id())
+
     def _activate(self):
-        self.palette.popdown(immediate=True)
-        if self._journal_entries:
-            entry = self._journal_entries[0]
+        if self.palette is not None:
+            self.palette.popdown(immediate=True)
 
-            if not entry['activity_id']:
-                entry['activity_id'] = activityfactory.create_activity_id()
-
-            shell_model = shell.get_model()
-            activity = shell_model.get_activity_by_id(entry['activity_id'])
-            if activity:
-                activity.get_window().activate(gtk.get_current_event_time())
-                return
-
-            launcher.add_launcher(entry['activity_id'],
-                                  self._activity_info.get_icon(),
-                                  XoColor(entry.get('icon-color', '')))
-            journal.misc.resume(entry, self._activity_info.get_bundle_id())
+        if self._resume_mode and self._journal_entries:
+            self._resume(self._journal_entries[0])
         else:
             client = gconf.client_get_default()
             xo_color = XoColor(client.get_string('/desktop/sugar/user/color'))
@@ -552,20 +559,29 @@ class ActivityIcon(CanvasIcon):
         return registry.get_bundle_position(self.bundle_id, self.version)
     fixed_position = property(_get_fixed_position, None)
 
+    def set_resume_mode(self, resume_mode):
+        self._resume_mode = resume_mode
+        self._update()
+
 class FavoritePalette(ActivityPalette):
     __gtype_name__ = 'SugarFavoritePalette'
 
+    __gsignals__ = {
+        'entry-activate': (gobject.SIGNAL_RUN_FIRST,
+                           gobject.TYPE_NONE, ([object])),
+    }
+
     def __init__(self, activity_info, journal_entries):
         ActivityPalette.__init__(self, activity_info)
 
-        if journal_entries and journal_entries[0].get('icon-color', ''):
-            color = XoColor(journal_entries[0]['icon-color'])
+        if not journal_entries:
+            xo_color = XoColor('%s,%s' % (style.COLOR_BUTTON_GREY.get_svg(),
+                                          style.COLOR_TRANSPARENT.get_svg()))
         else:
-            color = XoColor('%s,%s' % (style.COLOR_BUTTON_GREY.get_svg(),
-                                       style.COLOR_WHITE.get_svg()))
+            xo_color = misc.get_icon_color(journal_entries[0])
 
         self.props.icon = Icon(file=activity_info.get_icon(),
-                               xo_color=color,
+                               xo_color=xo_color,
                                icon_size=gtk.ICON_SIZE_LARGE_TOOLBAR)
 
         if journal_entries:
@@ -573,8 +589,8 @@ class FavoritePalette(ActivityPalette):
 
             menu_items = []
             for entry in journal_entries:
-                icon_file_name = journal.misc.get_icon_name(entry)
-                color = XoColor(entry.get('icon-color', None))
+                icon_file_name = misc.get_icon_name(entry)
+                color = misc.get_icon_color(entry)
 
                 menu_item = MenuItem(text_label=entry['title'],
                                      file_name=icon_file_name,
@@ -593,7 +609,7 @@ class FavoritePalette(ActivityPalette):
 
     def __resume_entry_cb(self, menu_item, entry):
         if entry is not None:
-            journal.misc.resume(entry, entry['activity'])
+            self.emit('entry-activate', entry)
 
 class CurrentActivityIcon(CanvasIcon, hippo.CanvasItem):
     def __init__(self):
@@ -610,7 +626,8 @@ class CurrentActivityIcon(CanvasIcon, hippo.CanvasItem):
         self.connect('button-release-event', self.__button_release_event_cb)
 
     def __button_release_event_cb(self, icon, event):
-        self._home_model.get_active_activity().get_window().activate(1)
+        window = self._home_model.get_active_activity().get_window()
+        window.activate(gtk.get_current_event_time())
 
     def _update(self):
         self.props.file_name = self._home_activity.get_icon_path()
@@ -672,16 +689,16 @@ class _MyIcon(MyIcon):
         self.emit('register-activate')
 
     def remove_register_menu(self):
-        self.palette.menu.remove(self._register_menu)
+        self.palette.remove(self._register_menu)
 
 class FavoritesSetting(object):
 
     _FAVORITES_KEY = "/desktop/sugar/desktop/favorites_layout"
 
     def __init__(self):
-        client = gconf.client_get_default() 
+        client = gconf.client_get_default()
         self._layout = client.get_string(self._FAVORITES_KEY)
-        logging.debug('FavoritesSetting layout %r' % (self._layout))
+        logging.debug('FavoritesSetting layout %r', self._layout)
 
         self._mode = None
 
@@ -691,7 +708,7 @@ class FavoritesSetting(object):
         return self._layout
 
     def set_layout(self, layout):
-        logging.debug('set_layout %r %r' % (layout, self._layout))
+        logging.debug('set_layout %r %r', layout, self._layout)
         if layout != self._layout:
             self._layout = layout
 
